time

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 14, 2025 License: MIT Imports: 4 Imported by: 2

README

flam-time

flam-time is a flam-in-go extension to provide a time and trigger proxy module

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewProvider

func NewProvider() flam.Provider

Types

type Callback

type Callback func() error

type Facade

type Facade interface {
	ParseDuration(s string) (time.Duration, error)
	Since(t time.Time) time.Duration
	Until(t time.Time) time.Duration
	FixedZone(name string, offset int) *time.Location
	LoadLocation(name string) (*time.Location, error)
	Date(year int, month time.Month, day, hour, min, sec, nsec int, loc *time.Location) time.Time
	Now() time.Time
	Parse(layout, value string) (time.Time, error)
	ParseInLocation(layout, value string, loc *time.Location) (time.Time, error)
	Unix(sec int64, nsec int64) time.Time
	UnixMicro(usec int64) time.Time
	UnixMilli(msec int64) time.Time

	NewPulseTrigger(delay time.Duration, callback Callback) (Trigger, error)
	NewRecurringTrigger(delay time.Duration, callback Callback) (Trigger, error)
}

type Trigger

type Trigger interface {
	io.Closer

	IsClosed() bool
	Delay() time.Duration
}

Jump to